<?php
/**
 * Default theme options.
 *
 * @package Fotoografia
 */

if ( ! function_exists( 'fotoografia_get_default_theme_options' ) ) :

	/**
	 * Get default theme options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Default theme options.
	 */
function fotoografia_get_default_theme_options() {

	$theme_data = wp_get_theme();
	$defaults = array();

	$defaults['disable_homepage_content_section'] 			= true;


	// Featured Slider Section
	$defaults['disable_featured-slider_section']	= false;
	$defaults['sr_content_type']			= 'sr_post';
	$defaults['slider_speed']				= 800;

//Details Section	
	$defaults['disable_details_section']	   	= false;
	$defaults['details_button_label']	   	 	= esc_html__( 'Purchase Now', 'fotoografia' );
	$defaults['details_button_url']	   	 		= '#';


// Project Section
	$defaults['disable_featured_section']	= false;
	$defaults['featured_title']	   		= esc_html__( 'My Latest Projects', 'fotoografia' );
	$defaults['number_of_featured_items']	= 5;
	$defaults['featured_content_type']		= 'featured_post';
	$defaults['featured_layout_option']			= 'default-featured';

	// Our Service Section
	$defaults['disable_services_section']	= false;
	$defaults['services_title']	   	 		= esc_html__( 'Reasons to Choose My Services', 'fotoografia' );
	$defaults['services_content_type']		= 'service_post';
	$defaults['disable_services_icon']		= true;

	//Cta Section	
	$defaults['disable_cta_section']	   	= false;
	$defaults['background_cta_section']		= get_template_directory_uri() .'/assets/images/default-header.jpg';
	$defaults['cta_button_label']	   	 	= esc_html__( 'Purchase Now', 'fotoografia' );
	$defaults['cta_button_url']	   	 		= '#';
	$defaults['cta_alt_button_label']	   	= esc_html__( 'Contact Us', 'fotoografia' );
	$defaults['cta_alt_button_url']	   	 	= '#';


	// About Section
	$defaults['disable_about_section']	= false;
	$defaults['about_title']	   	 	= esc_html__( '“....... It’s one thing to make a picture of what a person looks like, it’s another thing to make a portrait of who they are.” ', 'fotoografia' );
	$defaults['number_of_about_column']			= 4;
	$defaults['about_content_type']			= 'about_post';
	$defaults['about_layout_option']			= 'default-about';


	// Testimonial Section
	$defaults['disable_testimonial_section']	= false;
	$defaults['testimonial_title']	   	 		= esc_html__( 'Happy Customer', 'fotoografia' );
	$defaults['testimonial_content_type']		= 'testimonial_category';


	// Single Post Option
	$defaults['single_page_video_enable']		= true;
	$defaults['single_page_image_enable']		= true;
	$defaults['single_page_header_image_enable']		= true;
	$defaults['single_page_header_image_as_header_image_enable']		= true;

	// Single Post Option
	$defaults['single_post_category_enable']		= true;
	$defaults['single_post_posted_on_enable']		= true;
	$defaults['single_post_author_enable']		= true;
	$defaults['single_post_video_enable']		= true;
	$defaults['single_post_comment_enable']		= true;
	$defaults['single_post_pagination_enable']		= true;
	$defaults['single_post_image_enable']		= true;
	$defaults['single_post_header_image_enable']		= true;
	$defaults['single_post_header_image_as_header_image_enable']		= true;

	// Latest Posts Section

	$defaults['number_of_archive_posts_column']	= 3;
	$defaults['pagination_type']		= 'default';
	$defaults['archive_category_enable']		= true;
	$defaults['archive_posted_on_enable']		= true;
	$defaults['archive_author_enable']		= true;
	$defaults['archive_image_enable']		= true;
	$defaults['archive_header_image_enable']		= true;
	$defaults['archive_layout_option']		= 'grid-layout';
	$defaults['archive_text_align_option']		= 'center';

	//General Section
	$defaults['readmore_text']				= esc_html__('Read More','fotoografia');
	$defaults['excerpt_length']				= 20;
	$defaults['layout_options_blog']			= 'right-sidebar';
	$defaults['layout_options_archive']			= 'right-sidebar';
	$defaults['layout_options_page']			= 'right-sidebar';	
	$defaults['layout_options_single']			= 'right-sidebar';	

	//Footer section 		
	$defaults['copyright_text']				= esc_html__( 'Copyright &copy; All rights reserved.', 'fotoografia' );

	// Pass through filter.
	$defaults = apply_filters( 'fotoografia_filter_default_theme_options', $defaults );
	return $defaults;
}

endif;

/**
*  Get theme options
*/
if ( ! function_exists( 'fotoografia_get_option' ) ) :

	/**
	 * Get theme option
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Option key.
	 * @return mixed Option value.
	 */
	function fotoografia_get_option( $key ) {

		$default_options = fotoografia_get_default_theme_options();
		if ( empty( $key ) ) {
			return;
		}

		$theme_options = (array)get_theme_mod( 'theme_options' );
		$theme_options = wp_parse_args( $theme_options, $default_options );

		$value = null;

		if ( isset( $theme_options[ $key ] ) ) {
			$value = $theme_options[ $key ];
		}

		return $value;

	}

endif;