<?php
/**
 * Must Download options.
 *
 * @package Fotoografia
 */

$default = fotoografia_get_default_theme_options();

// Must Download Author Section
$wp_customize->add_section( 'section_home_about',
	array(
		'title'      => __( 'Must Download Section', 'fotoografia' ),
		'priority'   => 35,
		'capability' => 'edit_theme_options',
		'panel'      => 'home_page_panel',
		)
);

$wp_customize->add_setting( 'theme_options[disable_about_section]',
	array(
		'default'           => $default['disable_about_section'],
		'type'              => 'theme_mod',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'fotoografia_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Fotoografia_Switch_Control( $wp_customize, 'theme_options[disable_about_section]',
    array(
		'label' 			=> __('Enable/Disable Must Download Section', 'fotoografia'),
		'section'    		=> 'section_home_about',
		 'settings'  		=> 'theme_options[disable_about_section]',
		'on_off_label' 		=> fotoografia_switch_options(),
    )
) );

//Sensational Section title
$wp_customize->add_setting('theme_options[about_title]', 
	array(
	'default'           => $default['about_title'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_text_field'
	)
);

$wp_customize->add_control('theme_options[about_title]', 
	array(
	'label'       => __('Section Title', 'fotoografia'),
	'section'     => 'section_home_about',   
	'settings'    => 'theme_options[about_title]',
	'active_callback' => 'fotoografia_about_active',		
	'type'        => 'text'
	)
);
// Number of items
$wp_customize->add_setting('theme_options[number_of_about_column]', 
	array(
	'default' 			=> $default['number_of_about_column'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'fotoografia_sanitize_number_range'
	)
);

$wp_customize->add_control('theme_options[number_of_about_column]', 
	array(
	'label'       => __('Number Of Download Column', 'fotoografia'),
	'description' => __('Save & Refresh the customizer to see its effect. Maximum is 5.', 'fotoografia'),
	'section'     => 'section_home_about',   
	'settings'    => 'theme_options[number_of_about_column]',		
	'type'        => 'number',
	'active_callback' => 'fotoografia_about_active',
	'input_attrs' => array(
			'min'	=> 2,
			'max'	=> 5,
			'step'	=> 1,
		),
	)
);


$wp_customize->add_setting('theme_options[about_content_type]', 
	array(
	'default' 			=> $default['about_content_type'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'fotoografia_sanitize_select'
	)
);

$wp_customize->add_control('theme_options[about_content_type]', 
	array(
	'label'       => __('Content Type', 'fotoografia'),
	'section'     => 'section_home_about',   
	'settings'    => 'theme_options[about_content_type]',		
	'type'        => 'select',
	'active_callback' => 'fotoografia_about_active',
	'choices'	  => array(
			'about_post'	  => __('Post','fotoografia'),
			'about_category'	  => __('Category','fotoografia'),
		),
	)
);

// Setting  Team Category.
$wp_customize->add_setting( 'theme_options[about_category]',
	array(

	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	new Fotoografia_Dropdown_Taxonomies_Control( $wp_customize, 'theme_options[about_category]',
		array(
		'label'    => __( 'Select Category', 'fotoografia' ),
		'section'  => 'section_home_about',
		'settings' => 'theme_options[about_category]',	
		'active_callback' => 'fotoografia_about_category',		
		)
	)
);

for( $i=1; $i<=6; $i++ ){

	// Posts
	$wp_customize->add_setting('theme_options[about_post_'.$i.']', 
		array(
		'type'              => 'theme_mod',
		'capability'        => 'edit_theme_options',	
		'sanitize_callback' => 'fotoografia_dropdown_pages'
		)
	);

	$wp_customize->add_control('theme_options[about_post_'.$i.']', 
		array(
		'label'       => sprintf( __('Select Post #%1$s', 'fotoografia'), $i),
		'section'     => 'section_home_about',   
		'settings'    => 'theme_options[about_post_'.$i.']',		
		'type'        => 'select',
		'choices'	  => fotoografia_post_choices(),
		'active_callback' => 'fotoografia_about_post',
		)
	);
}