<?php
/**
 * Latest Project options.
 *
 * @package Fotoografia
 */

$default = fotoografia_get_default_theme_options();

// Latest Project Section
$wp_customize->add_section( 'section_home_featured',
	array(
		'title'      => __( 'Latest Project', 'fotoografia' ),
		'priority'   => 20,
		'capability' => 'edit_theme_options',
		'panel'      => 'home_page_panel',
		)
);

$wp_customize->add_setting( 'theme_options[disable_featured_section]',
	array(
		'default'           => $default['disable_featured_section'],
		'type'              => 'theme_mod',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'fotoografia_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Fotoografia_Switch_Control( $wp_customize, 'theme_options[disable_featured_section]',
    array(
		'label' 			=> __('Enable/Disable Latest Project Section', 'fotoografia'),
		'section'    		=> 'section_home_featured',
		'settings'  		=> 'theme_options[disable_featured_section]',
		'on_off_label' 		=> fotoografia_switch_options(),
    )
) );

//Sensational Section title
$wp_customize->add_setting('theme_options[featured_title]', 
	array(
	'default'           => $default['featured_title'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_text_field'
	)
);

$wp_customize->add_control('theme_options[featured_title]', 
	array(
	'label'       => __('Section Title', 'fotoografia'),
	'section'     => 'section_home_featured',   
	'settings'    => 'theme_options[featured_title]',
	'active_callback' => 'fotoografia_featured_active',		
	'type'        => 'text'
	)
);

// Number of items
$wp_customize->add_setting('theme_options[number_of_featured_items]', 
	array(
	'default' 			=> $default['number_of_featured_items'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'fotoografia_sanitize_number_range'
	)
);

$wp_customize->add_control('theme_options[number_of_featured_items]', 
	array(
	'label'       => __('Number Of Latest Project', 'fotoografia'),
	'description' => __('Save & Refresh the customizer to see its effect. Maximum is 10.', 'fotoografia'),
	'section'     => 'section_home_featured',   
	'settings'    => 'theme_options[number_of_featured_items]',		
	'type'        => 'number',
	'active_callback' => 'fotoografia_featured_active',
	'input_attrs' => array(
			'min'	=> 1,
			'max'	=> 10,
			'step'	=> 1,
		),
	)
);

$wp_customize->add_setting('theme_options[featured_content_type]', 
	array(
	'default' 			=> $default['featured_content_type'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'fotoografia_sanitize_select'
	)
);

$wp_customize->add_control('theme_options[featured_content_type]', 
	array(
	'label'       => __('Content Type', 'fotoografia'),
	'section'     => 'section_home_featured',   
	'settings'    => 'theme_options[featured_content_type]',		
	'type'        => 'select',
	'active_callback' => 'fotoografia_featured_active',
	'choices'	  => array(
			'featured_post'	  => __('Post','fotoografia'),
			'featured_category'  => __('Category', 'fotoografia'),
		),
	)
);

// Setting  Latest Project Category.
$wp_customize->add_setting( 'theme_options[featured_category]',
	array(

	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'absint',
	)
);
$wp_customize->add_control(
	new Fotoografia_Dropdown_Taxonomies_Control( $wp_customize, 'theme_options[featured_category]',
		array(
		'label'    => __( 'Select Category', 'fotoografia' ),
		'section'  => 'section_home_featured',
		'settings' => 'theme_options[featured_category]',	
		'active_callback' => 'fotoografia_featured_category',		
		)
	)
);

$number_of_featured_items = fotoografia_get_option( 'number_of_featured_items' );

for( $i=1; $i<=$number_of_featured_items; $i++ ){

	// Additional Information First Post
	$wp_customize->add_setting('theme_options[featured_post_'.$i.']', 
		array(
		'type'              => 'theme_mod',
		'capability'        => 'edit_theme_options',	
		'sanitize_callback' => 'fotoografia_dropdown_posts'
		)
	);
	$wp_customize->add_control( new Fotoografia_Dropdown_Chooser( $wp_customize,'theme_options[featured_post_'.$i.']', 
		array(
		'label'       => sprintf( __('Select Post #%1$s', 'fotoografia'), $i),
		'section'     => 'section_home_featured',  
		'settings'    => 'theme_options[featured_post_'.$i.']',	
		'choices'			=> fotoografia_post_choices(),	
		'type'        => 'dropdown-posts',
		'active_callback' => 'fotoografia_featured_post',
		)
	));
}
